@@ -10,6 +10,7 @@ ggemmeans <- function(model,
                       typical = "mean",
                       condition = NULL,
                       back.transform = TRUE,
+                      interval = "confidence",
                       ...) {
 
   if (!requireNamespace("emmeans")) {
@@ -17,14 +18,34 @@ ggemmeans <- function(model,
   }
 
   # check arguments
-  type <- match.arg(type, choices = c("fe", "fe.zi", "re", "re.zi"))
+  type <- match.arg(type, choices = c("fe", "fixed", "count", "re", "random", "fe.zi", "zero_inflated", "re.zi", "zi_random", "zero_inflated_random", "zi.prob", "zi_prob"))
+  interval <- match.arg(interval, choices = c("confidence", "prediction"))
   model_name <- deparse(substitute(model))
 
+  type <- switch(
+    type,
+    "fixed" = ,
+    "count" = "fe",
+    "random" = "re",
+    "zi" = ,
+    "zero_inflated" = "fe.zi",
+    "zi_random" = ,
+    "zero_inflated_random" = "re.zi",
+    "zi_prob" = "zi.prob",
+    "survival" = "surv",
+    "cumulative_hazard" = "cumhaz"    ,
+    type
+  )
+
   # check if terms are a formula
   if (!missing(terms) && !is.null(terms) && inherits(terms, "formula")) {
     terms <- all.vars(terms)
   }
 
+  if (inherits(model, c("glmmTMB", "MixMod")) && type == "zi.prob") {
+    stop(sprintf("This prediction-type is currently not available for models of class '%s'.", class(model)[1]), call. = FALSE)
+  }
+
   # for gamm/gamm4 objects, we have a list with two items, mer and gam
   # extract just the mer-part then
   if (is.gamm(model) || is.gamm4(model)) model <- model$gam
@@ -76,7 +97,7 @@ ggemmeans <- function(model,
     # get prediction mode, i.e. at which scale predicted
     # values should be returned
     pmode <- .get_prediction_mode_argument(model, model_info, type)
-    prediction_data <- .emmeans_prediction_data(model, data_grid, cleaned_terms, ci.lvl, pmode, type, model_info, ...)
+    prediction_data <- .emmeans_prediction_data(model, data_grid, cleaned_terms, ci.lvl, pmode, type, model_info, interval = interval, ...)
 
     # fix gam here
     if (inherits(model, "gam") && model_info$is_zero_inflated) {
@@ -91,8 +112,8 @@ ggemmeans <- function(model,
 
   attr(prediction_data, "continuous.group") <- attr(data_grid, "continuous.group")
 
-  if (model_info$is_ordinal | model_info$is_categorical) {
-    colnames(prediction_data)[1] <- "response.level"
+  if (model_info$is_ordinal || model_info$is_categorical || model_info$is_multinomial) {
+    if (colnames(prediction_data)[1] != "x") colnames(prediction_data)[1] <- "response.level"
   }
 
   result <- .post_processing_predictions(
@@ -147,9 +168,11 @@ ggemmeans <- function(model,
     "asymptotic"
   else if (inherits(model, "MixMod"))
     "fixed-effects"
-  else if (inherits(model, "gls"))
-    "satterthwaite"
-  else if (model_info$is_ordinal | model_info$is_categorical)
+  else if (inherits(model, c("gls", "lme")))
+    "auto"
+  else if (inherits(model, "MCMCglmm") && model_info$is_multinomial)
+    "response"
+  else if (model_info$is_ordinal || model_info$is_categorical || model_info$is_multinomial)
     "prob"
   else if (model_info$is_zero_inflated && type %in% c("fe", "re") && inherits(model, "glmmTMB"))
     "link"
@@ -157,6 +180,8 @@ ggemmeans <- function(model,
     "response"
   else if (model_info$is_zero_inflated && type %in% c("fe", "re"))
     "count"
+  else if (model_info$is_zero_inflated && type %in% c("zi.prob"))
+    "prob0"
   else
     "link"
 }
