@@ -8,7 +8,7 @@
 #'   constant and varying the focal variable(s). \cr \cr
 #'   \code{ggpredict()} uses \code{predict()} for generating predictions,
 #'   while \code{ggeffect()} computes marginal effects by internally calling
-#'   \code{\link[effects]{Effect}} and \code{ggemmeans()} uses \code{\link[emmeans]{emmeans}}.
+#'   \code{effects::Effect()} and \code{ggemmeans()} uses \code{emmeans::emmeans()}.
 #'   The result is returned as consistent data frame.
 #'
 #' @param model A fitted model object, or a list of model objects. Any model
@@ -35,12 +35,12 @@
 #'   for more details.
 #' @param type Character, only applies for survival models, mixed effects models
 #'   and/or models with zero-inflation. \strong{Note:} For \code{brmsfit}-models
-#'   with zero-inflation component, there is no \code{type = "fe.zi"} nor
-#'   \code{type = "re.zi"}; predicted values for \code{MixMod}-models from
+#'   with zero-inflation component, there is no \code{type = "zero_inflated"} nor
+#'   \code{type = "zi_random"}; predicted values for \code{MixMod}-models from
 #'   \pkg{GLMMadaptive} with zero-inflation component \emph{always} condition on
 #'   the zero-inflation part of the model (see 'Details').
 #'   \describe{
-#'     \item{\code{"fe"}}{
+#'     \item{\code{"fixed"} (or \code{"fe"} or \code{"count"})}{
 #'     Predicted values are conditioned on the fixed effects or conditional
 #'     model only (for mixed models: predicted values are on the population-level
 #'     and \emph{confidence intervals} are returned). For instance, for models
@@ -50,10 +50,10 @@
 #'     \code{predict(..., type = "link")} (however, predicted values are
 #'     back-transformed to the response scale).
 #'     }
-#'     \item{\code{"re"}}{
-#'     This only applies to mixed models, and \code{type = "re"} does not
-#'     condition on the zero-inflation component of the model. \code{type = "re"}
-#'     still returns population-level predictions, however, unlike \code{type = "fe"},
+#'     \item{\code{"random"} (or \code{"re"})}{
+#'     This only applies to mixed models, and \code{type = "random"} does not
+#'     condition on the zero-inflation component of the model. \code{type = "random"}
+#'     still returns population-level predictions, however, unlike \code{type = "fixed"},
 #'     intervals also consider the uncertainty in the variance parameters (the
 #'     mean random effect variance, see \cite{Johnson et al. 2014} for details)
 #'     and hence can be considered as \emph{prediction intervals}. For models
@@ -65,7 +65,7 @@
 #'     name of the related random effect term to the \code{terms}-argument
 #'     (for more details, see \href{https://strengejacke.github.io/ggeffects/articles/introduction_effectsatvalues.html}{this vignette}).
 #'     }
-#'     \item{\code{"fe.zi"}}{
+#'     \item{\code{"zero_inflated"} (or \code{"fe.zi"} or \code{"zi"})}{
 #'     Predicted values are conditioned on the fixed effects and the zero-inflation
 #'     component. For instance, for models fitted with \code{zeroinfl}
 #'     from \pkg{pscl}, this would return the predicted response (\code{mu*(1-p)})
@@ -75,7 +75,7 @@
 #'     zero-inflation component, this type calls \code{predict(..., type = "response")}.
 #'     See 'Details'.
 #'     }
-#'     \item{\code{"re.zi"}}{
+#'     \item{\code{"zi_random"} (or \code{"re.zi"} or \code{"zero_inflated_random"})}{
 #'     Predicted values are conditioned on the zero-inflation component and
 #'     take the random effects uncertainty into account. For models fitted with
 #'     \code{glmmTMB()}, \code{hurdle()} or \code{zeroinfl()}, this would return the
@@ -83,6 +83,12 @@
 #'     also consider the uncertainty in the random effects variances. This
 #'     type calls \code{predict(..., type = "response")}. See 'Details'.
 #'     }
+#'     \item{\code{"zi_prob"} (or \code{"zi.prob"})}{
+#'     Predicted zero-inflation probability. For \pkg{glmmTMB} models with
+#'     zero-inflation component, this type calls \code{predict(..., type = "zlink")};
+#'     models from \pkg{pscl} call \code{predict(..., type = "zero")} and for
+#'     \pkg{GLMMadaptive}, \code{predict(..., type = "zero_part")} is called.
+#'     }
 #'     \item{\code{"sim"}}{
 #'     Predicted values and confidence resp. prediction intervals are
 #'     based on simulations, i.e. calls to \code{simulate()}. This type
@@ -90,22 +96,22 @@
 #'     random effects variances. Currently supported models are \code{glmmTMB}
 #'     and \code{merMod}. See \code{...} for details on number of simulations.
 #'     }
-#'     \item{\code{"surv"} and \code{"cumhaz"}}{
+#'     \item{\code{"survival"} and \code{"cumulative_hazard"} (or \code{"surv"} and \code{"cumhaz"})}{
 #'     Applies only to \code{coxph}-objects from the \pkg{survial}-package and
 #'     calculates the survival probability or the cumulative hazard of an event.
 #'     }
 #'   }
 #' @param typical Character vector, naming the function to be applied to the
 #'   covariates over which the effect is "averaged". The default is "mean".
-#'   See \code{\link[sjmisc]{typical_value}} for options.
+#'   See \code{?sjmisc::typical_value} for options.
 #' @param back.transform Logical, if \code{TRUE} (the default), predicted values
-#'   for log- or log-log transformend responses will be back-transformed to
+#'   for log- or log-log transformed responses will be back-transformed to
 #'   original response-scale.
 #' @param ppd Logical, if \code{TRUE}, predictions for Stan-models are
 #'   based on the posterior predictive distribution
-#'   (\code{\link[rstantools]{posterior_predict}}). If \code{FALSE} (the
+#'   (\code{rstantools::posterior_predict()}). If \code{FALSE} (the
 #'   default), predictions are based on posterior draws of the linear
-#'   predictor (\code{\link[rstantools]{posterior_linpred}}).
+#'   predictor (\code{rstantools::posterior_linpred()}).
 #' @param condition Named character vector, which indicates covariates that
 #'   should be held constant at specific values. Unlike \code{typical}, which
 #'   applies a function to the covariates to determine the value that is used
@@ -116,9 +122,10 @@
 #'   (default) or \code{"prediction"}. May be abbreviated. Unlike
 #'   \emph{confidence intervals}, \emph{prediction intervals} include the
 #'   residual variance (sigma^2). This argument is ignored for mixed models,
-#'   as \code{interval = "prediction"} is equivalent to \code{type = "re"}
-#'   (and \code{interval = "confidence"} is equivalent to \code{type = "fe"}).
-#'   Note that prediction intervals are not available for all models.
+#'   as \code{interval = "prediction"} is equivalent to \code{type = "random"}
+#'   (and \code{interval = "confidence"} is equivalent to \code{type = "fixed"}).
+#'   Note that prediction intervals are not available for all models, but only
+#'   for models that work with \code{insight::get_sigma()}.
 #' @param vcov.fun String, indicating the name of the \code{vcov*()}-function
 #'    from the \pkg{sandwich} or \pkg{clubSandwich}-package, e.g.
 #'    \code{vcov.fun = "vcovCL"}, which is used to compute (cluster) robust
@@ -128,14 +135,14 @@
 #'    all model objects that work with \code{ggpredict()} are also supported
 #'    by the \pkg{sandwich} or \pkg{clubSandwich}-package.
 #' @param vcov.type Character vector, specifying the estimation type for the
-#'    robust covariance matrix estimation (see \code{\link[sandwich]{vcovHC}}
-#'    or \code{\link[clubSandwich]{vcovCR}} for details).
+#'    robust covariance matrix estimation (see \code{?sandwich::vcovHC}
+#'    or \code{?clubSandwich::vcovCR} for details).
 #' @param vcov.args List of named vectors, used as additional arguments that
 #'    are passed down to \code{vcov.fun}.
 #' @param ... For \code{ggpredict()}, further arguments passed down to
 #'    \code{predict()}; for \code{ggeffect()}, further arguments passed
-#'    down to \code{\link[effects]{Effect}}; and for \code{ggemmeans()},
-#'    further arguments passed down to \code{\link[emmeans]{emmeans}}.
+#'    down to \code{effects::Effect()}; and for \code{ggemmeans()},
+#'    further arguments passed down to \code{emmeans::emmeans()}.
 #'    If \code{type = "sim"}, \code{...} may also be used to set the number of
 #'    simulation, e.g. \code{nsim = 500}.
 #'
@@ -148,14 +155,19 @@
 #'   }
 #'   \subsection{Difference between \code{ggpredict()} and \code{ggeffect()} or \code{ggemmeans()}}{
 #'   \code{ggpredict()} calls \code{predict()}, while \code{ggeffect()}
-#'   calls \code{\link[effects]{Effect}} and \code{ggemmeans()} calls
-#'   \code{\link[emmeans]{emmeans}} to compute marginal effects. Therefore,
-#'   \code{ggpredict()} and \code{ggeffect()} resp. \code{ggemmeans()} differ in
-#'   how factors are held constant: \code{ggpredict()} uses the reference level, while
-#'   \code{ggeffect()} and \code{ggemmeans()} compute a kind of "average" value,
-#'   which represents the proportions of each factor's category. Use \code{condition}
-#'   to set a specific level for factors in \code{ggemmeans()}, so factors are
-#'   not averaged over their categories, but held constant at a given level.
+#'   calls \code{effects::Effect()} and \code{ggemmeans()} calls
+#'   \code{emmeans::emmeans()} to compute marginal effects. Thus, effects returned
+#'   by \code{ggpredict()} can be described as \emph{conditional effects} (i.e.
+#'   these are conditioned on certain (reference) levels of factors), while
+#'   \code{ggemmeans()} and \code{ggeffect()} return \emph{marginal means}, since
+#'   the effects are "marginalized" (or "averaged") over the levels of factors.
+#'   Therefore, \code{ggpredict()} and \code{ggeffect()} resp. \code{ggemmeans()}
+#'   differ in how factors are held constant: \code{ggpredict()} uses the
+#'   reference level, while \code{ggeffect()} and \code{ggemmeans()} compute a
+#'   kind of "average" value, which represents the proportions of each factor's
+#'   category. Use \code{condition} to set a specific level for factors in
+#'   \code{ggemmeans()}, so factors are not averaged over their categories,
+#'   but held constant at a given level.
 #'   }
 #'   \subsection{Marginal Effects at Specific Values}{
 #'   Specific values of model terms can be specified via the \code{terms}-argument.
@@ -164,6 +176,8 @@
 #'   the levels in brackets must be separated by a whitespace character, e.g.
 #'   \code{terms = c("age", "education [1,3]")}. Numeric ranges, separated
 #'   with colon, are also allowed: \code{terms = c("education", "age [30:60]")}.
+#'   The stepsize for range can be adjusted using `by`, e.g.
+#'   \code{terms = "age [30:60 by=5]"}.
 #'   \cr \cr
 #'   The \code{terms}-argument also supports the same shortcuts as the
 #'   \code{values}-argument in \code{values_at()}. So
@@ -179,6 +193,10 @@
 #'   It is also possible to define own functions (see
 #'   \href{https://strengejacke.github.io/ggeffects/articles/introduction_effectsatvalues.html}{this vignette}).
 #'   \cr \cr
+#'   Instead of a function, it is also possible to define the name of a variable
+#'   with specific values, e.g. to define a vector \code{v = c(1000, 2000, 3000)} and
+#'   then use \code{terms = "income [v]"}.
+#'   \cr \cr
 #'   You can take a random sample of any size with \code{sample=n}, e.g
 #'   \code{terms = "income [sample=8]"}, which will sample eight values from
 #'   all possible values of the variable \code{income}. This option is especially
@@ -223,24 +241,24 @@
 #'   values are the median value of all drawn posterior samples. The
 #'   confidence intervals for Stan-models are Bayesian predictive intervals.
 #'   By default (i.e. \code{ppd = FALSE}), the predictions are based on
-#'   \code{\link[rstantools]{posterior_linpred}} and hence have some
+#'   \code{rstantools::posterior_linpred()} and hence have some
 #'   limitations: the uncertainty of the error term is not taken into
 #'   account. The recommendation is to use the posterior predictive
-#'   distribution (\code{\link[rstantools]{posterior_predict}}).
+#'   distribution (\code{rstantools::posterior_predict()}).
 #'   }
 #'   \subsection{Zero-Inflated and Zero-Inflated Mixed Models with brms}{
 #'   Models of class \code{brmsfit} always condition on the zero-inflation
 #'   component, if the model has such a component. Hence, there is no
-#'   \code{type = "fe.zi"} nor \code{type = "re.zi"} for \code{brmsfit}-models,
+#'   \code{type = "zero_inflated"} nor \code{type = "zi_random"} for \code{brmsfit}-models,
 #'   because predictions are based on draws of the posterior distribution,
 #'   which already account for the zero-inflation part of the model.
 #'   }
 #'   \subsection{Zero-Inflated and Zero-Inflated Mixed Models with glmmTMB}{
 #'   If \code{model} is of class \code{glmmTMB}, \code{hurdle}, \code{zeroinfl}
 #'   or \code{zerotrunc}, simulations from a multivariate normal distribution
-#'   (see \code{\link[MASS]{mvrnorm}}) are drawn to calculate \code{mu*(1-p)}.
+#'   (see \code{?MASS::mvrnorm}) are drawn to calculate \code{mu*(1-p)}.
 #'   Confidence intervals are then based on quantiles of these results. For
-#'   \code{type = "re.zi"}, prediction intervals also take the uncertainty in
+#'   \code{type = "zi_random"}, prediction intervals also take the uncertainty in
 #'   the random-effect paramters into account (see also Brooks et al. 2017,
 #'   pp.391-392 for details).
 #'   \cr \cr
@@ -250,14 +268,14 @@
 #'   details).
 #'   }
 #'   \subsection{MixMod-models from GLMMadaptive}{
-#'   Predicted values for the fixed effects component (\code{type = "fe"} or
-#'   \code{type = "fe.zi"}) are based on \code{predict(..., type = "mean_subject")},
-#'   while predicted values for random effects components (\code{type = "re"} or
-#'   \code{type = "re.zi"}) are calculated with \code{predict(..., type = "subject_specific")}
+#'   Predicted values for the fixed effects component (\code{type = "fixed"} or
+#'   \code{type = "zero_inflated"}) are based on \code{predict(..., type = "mean_subject")},
+#'   while predicted values for random effects components (\code{type = "random"} or
+#'   \code{type = "zi_random"}) are calculated with \code{predict(..., type = "subject_specific")}
 #'   (see \code{?GLMMadaptive::predict.MixMod} for details). The latter option
 #'   requires the response variable to be defined in the \code{newdata}-argument
 #'   of \code{predict()}, which will be set to its typical value (see
-#'   \code{\link[sjmisc]{typical_value}}).
+#'   \code{?sjmisc::typical_value}).
 #'   }
 #'
 #' @references \itemize{
@@ -291,7 +309,7 @@
 #'         \describe{
 #'           \item{\code{x}}{the values of the first term in \code{terms}, used as x-position in plots.}
 #'           \item{\code{predicted}}{the predicted values of the response, used as y-position in plots.}
-#'           \item{\code{std.error}}{the standard error of the predictions.}
+#'           \item{\code{std.error}}{the standard error of the predictions. \emph{Note that the standard errors are always on the link-scale, and not back-transformed for non-Gaussian models!}}
 #'           \item{\code{conf.low}}{the lower bound of the confidence interval for the predicted values.}
 #'           \item{\code{conf.high}}{the upper bound of the confidence interval for the predicted values.}
 #'           \item{\code{group}}{the grouping level from the second term in \code{terms}, used as grouping-aesthetics in plots.}
@@ -299,8 +317,8 @@
 #'         }
 #'         The estimated marginal means (predicted values) are always on the
 #'         response scale! \cr \cr
-#'         For proportional odds logistic regression (see \code{\link[MASS]{polr}})
-#'         resp. cumulative link models (e.g., see \code{\link[ordinal]{clm}}),
+#'         For proportional odds logistic regression (see \code{?MASS::polr})
+#'         resp. cumulative link models (e.g., see \code{?ordinal::clm}),
 #'         an additional column \code{response.level} is returned, which indicates
 #'         the grouping of predictions based on the level of the model's response.
 #'         \cr \cr Note that for convenience reasons, the columns for the intervals
@@ -421,10 +439,25 @@ ggpredict <- function(model,
                       interval = "confidence",
                       ...) {
   # check arguments
-  type <- match.arg(type, choices = c("fe", "re", "fe.zi", "re.zi", "sim", "surv", "cumhaz", "debug"))
+  type <- match.arg(type, choices = c("fe", "fixed", "count", "re", "random", "fe.zi", "zero_inflated", "re.zi", "zi_random", "zero_inflated_random", "zi.prob", "zi_prob", "sim", "surv", "survival", "cumhaz", "cumulative_hazard", "debug"))
   interval <- match.arg(interval, choices = c("confidence", "prediction"))
   model.name <- deparse(substitute(model))
 
+  type <- switch(
+    type,
+    "fixed" = ,
+    "count" = "fe",
+    "random" = "re",
+    "zi" = ,
+    "zero_inflated" = "fe.zi",
+    "zi_random" = ,
+    "zero_inflated_random" = "re.zi",
+    "zi_prob" = "zi.prob",
+    "survival" = "surv",
+    "cumulative_hazard" = "cumhaz"    ,
+    type
+  )
+
   # check if terms are a formula
   if (!missing(terms) && !is.null(terms) && inherits(terms, "formula")) {
     terms <- all.vars(terms)
