@@ -104,7 +104,7 @@
   # check for family, and set appropriate scale-title
   # if we have transformation through effects-package,
   # check if data is on original or transformed scale
-  ysc <- get_title_labels(fun, model_info, no.transform, type)
+  ysc <- .get_title_labels(fun, model_info, no.transform, type)
 
   # set plot-title
   t.title <-
@@ -150,13 +150,15 @@
 }
 
 
-get_title_labels <- function(fun, model_info, no.transform, type) {
+.get_title_labels <- function(fun, model_info, no.transform, type) {
   ysc <- "values"
 
-  if (fun == "glm") {
+  if (!is.null(type) && type == "zi.prob") {
+    ysc <- "zero-inflation probabilities"
+  } else if (fun == "glm") {
     if (model_info$is_brms_trial)
       ysc <- "successes"
-    else if (model_info$is_binomial || model_info$is_ordinal)
+    else if (model_info$is_binomial || model_info$is_ordinal || model_info$is_multinomial)
       ysc <- ifelse(isTRUE(no.transform), "log-odds", "probabilities")
     else if (model_info$is_count)
       ysc <- ifelse(isTRUE(no.transform), "log-mean", "counts")
