@@ -4,24 +4,23 @@ if (suppressWarnings(
   require("lme4") &&
   require("sjmisc")
 )) {
-  context("ggeffects, condition")
 
   data(efc)
   efc$e42dep <- to_label(efc$e42dep)
   fit <- lm(barthtot ~ c12hour + neg_c_7 + e42dep + c172code, data = efc)
 
   test_that("ggpredict, condition", {
-    ggpredict(fit, "c172code")
-    ggpredict(fit, "c172code", condition = c(c12hour = 40))
-    ggpredict(fit, "c172code", condition = c(c12hour = 40, e42dep = "severely dependent"))
-    ggpredict(fit, "c172code", condition = c(e42dep = "severely dependent"))
+    expect_s3_class(ggpredict(fit, "c172code"), "data.frame")
+    expect_s3_class(ggpredict(fit, "c172code", condition = c(c12hour = 40)), "data.frame")
+    expect_s3_class(ggpredict(fit, "c172code", condition = c(c12hour = 40, e42dep = "severely dependent")), "data.frame")
+    expect_s3_class(ggpredict(fit, "c172code", condition = c(e42dep = "severely dependent")), "data.frame")
   })
 
   test_that("ggemmeans, condition", {
-    ggemmeans(fit, "c172code")
-    ggemmeans(fit, "c172code", condition = c(c12hour = 40))
-    ggemmeans(fit, "c172code", condition = c(c12hour = 40, e42dep = "severely dependent"))
-    ggemmeans(fit, "c172code", condition = c(e42dep = "severely dependent"))
+    expect_s3_class(ggemmeans(fit, "c172code"), "data.frame")
+    expect_s3_class(ggemmeans(fit, "c172code", condition = c(c12hour = 40)), "data.frame")
+    expect_s3_class(ggemmeans(fit, "c172code", condition = c(c12hour = 40, e42dep = "severely dependent")), "data.frame")
+    expect_s3_class(ggemmeans(fit, "c172code", condition = c(e42dep = "severely dependent")), "data.frame")
   })
 
 
@@ -34,15 +33,15 @@ if (suppressWarnings(
   )
 
   test_that("ggpredict, glm", {
-    ggpredict(m1, "c12hour", condition = c(e42dep = "severely dependent"))
-    ggpredict(m1, c("c12hour", "c161sex"), condition = c(e42dep = "severely dependent"))
-    ggpredict(m1, c("c12hour", "c161sex", "c172code"), condition = c(e42dep = "severely dependent"))
+    expect_s3_class(ggpredict(m1, "c12hour", condition = c(e42dep = "severely dependent")), "data.frame")
+    expect_s3_class(ggpredict(m1, c("c12hour", "c161sex"), condition = c(e42dep = "severely dependent")), "data.frame")
+    expect_s3_class(ggpredict(m1, c("c12hour", "c161sex", "c172code"), condition = c(e42dep = "severely dependent")), "data.frame")
   })
 
   test_that("ggpredict, glm", {
-    ggemmeans(m1, "c12hour", condition = c(e42dep = "severely dependent"))
-    ggemmeans(m1, c("c12hour", "c161sex"), condition = c(e42dep = "severely dependent"))
-    ggemmeans(m1, c("c12hour", "c161sex", "c172code"), condition = c(e42dep = "severely dependent"))
+    expect_s3_class(ggemmeans(m1, "c12hour", condition = c(e42dep = "severely dependent")), "data.frame")
+    expect_s3_class(ggemmeans(m1, c("c12hour", "c161sex"), condition = c(e42dep = "severely dependent")), "data.frame")
+    expect_s3_class(ggemmeans(m1, c("c12hour", "c161sex", "c172code"), condition = c(e42dep = "severely dependent")), "data.frame")
   })
 
 
@@ -55,8 +54,8 @@ if (suppressWarnings(
   )
 
   test_that("ggpredict, glm", {
-    ggpredict(m2, "c12hour", condition = c(c172code = 1))
-    ggpredict(m2, c("c12hour", "c161sex"), condition = c(c172code = 2))
+    expect_s3_class(ggpredict(m2, "c12hour", condition = c(c172code = 1)), "data.frame")
+    expect_s3_class(ggpredict(m2, c("c12hour", "c161sex"), condition = c(c172code = 2)), "data.frame")
   })
 
 
